Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(50)

Unified Diff: chrome/utility/importer/firefox_importer.h

Issue 2296633002: Fix Firefox bookmarks import. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Cleanup Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/utility/importer/firefox_importer.h
diff --git a/chrome/utility/importer/firefox_importer.h b/chrome/utility/importer/firefox_importer.h
index 28bf603c89fe983d30e920775c4be6c44b8f0486..38a8b4d0c7ab879fdc4ce23fa511ae8e5daac2a1 100644
--- a/chrome/utility/importer/firefox_importer.h
+++ b/chrome/utility/importer/firefox_importer.h
@@ -59,9 +59,9 @@ class FirefoxImporter : public Importer {
struct BookmarkItem;
typedef std::vector<BookmarkItem*> BookmarkList;
- // Gets the specific IDs of bookmark root node from |db|.
- void LoadRootNodeID(sql::Connection* db, int* toolbar_folder_id,
- int* menu_folder_id, int* unsorted_folder_id);
+ // Gets the specific ID of bookmark node with given GUID from |db|.
+ // Returns -1 if not found.
+ int LoadNodeIDByGUID(sql::Connection* db, const std::string& GUID);
// Loads all livemark IDs from database |db|.
void LoadLivemarkIDs(sql::Connection* db, std::set<int>* livemark);

Powered by Google App Engine
This is Rietveld 408576698